@@ -1,7 +1,7 @@
 #!/bin/bash
 
 # The launcher is for people who want to run Goodvibes from the source tree,
-# without installing it. GLib and GTK+ need to access some shared resources,
+# without installing it. GLib and GTK need to access some shared resources,
 # so we need to tell them to look for it in-tree.
 
 fail() { echo >&2 "$@"; exit 1; }
@@ -13,7 +13,7 @@ GOODVIBES=$BUILDDIR/src/goodvibes
 [ -x $GOODVIBES ] || fail "Executable '$GOODVIBES' not found"
 
 # XDG_DATA_DIRS is needed for:
-# - GTK+ to load local icons from '$BUILDDIR/data/icons'
+# - GTK to load local icons from '$BUILDDIR/data/icons'
 [ "$XDG_DATA_DIRS" ] \
     && XDG_DATA_DIRS="$BUILDDIR/data:$XDG_DATA_DIRS" \
     || XDG_DATA_DIRS="$BUILDDIR/data:/usr/local/share:/usr/share"
@@ -25,4 +25,4 @@ export XDG_DATA_DIRS
 #   [GLib-GIO] Settings schema '...Goodvibes.Core' is not installed
 export GSETTINGS_SCHEMA_DIR="$BUILDDIR/data/"
 
-$GOODVIBES $@
+exec $GOODVIBES "$@"
