@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -19,8 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GOODVIBES_FRAMEWORK_GST_ADDITIONS_H__
-#define __GOODVIBES_FRAMEWORK_GST_ADDITIONS_H__
+#pragma once
 
 /*
  * Gst
@@ -28,5 +27,3 @@
 
 const gchar *gst_get_runtime_version_string(void);
 const gchar *gst_get_compile_version_string(void);
-
-#endif /* __GOODVIBES_FRAMEWORK_GST_ADDITIONS_H__ */
