@@ -22,7 +22,7 @@
 #include <glib.h>
 #include <gio/gio.h>
 
-#include "framework/gv-framework.h"
+#include "base/gv-base.h"
 
 #include "core/gv-engine.h"
 #include "core/gv-player.h"
@@ -154,7 +154,7 @@ gv_core_cleanup(void)
 }
 
 void
-gv_core_init(GApplication *application)
+gv_core_init(GApplication *application, const gchar *default_stations)
 {
 	GList *item;
 
@@ -169,7 +169,7 @@ gv_core_init(GApplication *application)
 	gv_core_settings = gv_get_settings(CORE_SCHEMA_ID_SUFFIX);
 	core_objects = g_list_append(core_objects, gv_core_settings);
 
-	gv_core_station_list = gv_station_list_new();
+	gv_core_station_list = gv_station_list_new_from_xdg_dirs(default_stations);
 	core_objects = g_list_append(core_objects, gv_core_station_list);
 
 	gv_core_engine = gv_engine_new();
@@ -178,9 +178,9 @@ gv_core_init(GApplication *application)
 	gv_core_player = gv_player_new(gv_core_engine, gv_core_station_list);
 	core_objects = g_list_append(core_objects, gv_core_player);
 
-	/* Register objects in the framework */
+	/* Register objects in the base */
 	for (item = core_objects; item; item = item->next) {
 		GObject *object = G_OBJECT(item->data);
-		gv_framework_register_object(object);
+		gv_base_register_object(object);
 	}
 }
