@@ -24,13 +24,14 @@
 #include <gst/gst.h>
 #include <gst/audio/streamvolume.h>
 
-#include "framework/glib-object-additions.h"
-#include "framework/gv-framework.h"
+#include "base/glib-object-additions.h"
+#include "base/gv-base.h"
 #include "core/gst-additions.h"
 #include "core/gv-core-enum-types.h"
 #include "core/gv-core-internal.h"
 #include "core/gv-metadata.h"
 #include "core/gv-station.h"
+#include "core/gv-streaminfo.h"
 
 #include "core/gv-engine.h"
 
@@ -51,8 +52,8 @@ enum {
 	PROP_0,
 	/* Properties - refer to class_init() for more details */
 	PROP_STATE,
-	PROP_BITRATE,
 	PROP_STATION,
+	PROP_STREAMINFO,
 	PROP_METADATA,
 	PROP_VOLUME,
 	PROP_MUTE,
@@ -74,8 +75,8 @@ struct _GvEnginePrivate {
 	GstBus        *bus;
 	/* Properties */
 	GvEngineState  state;
-	guint          bitrate;
 	GvStation     *station;
+	GvStreaminfo  *streaminfo;
 	GvMetadata    *metadata;
 	guint          volume;
 	gboolean       mute;
@@ -83,7 +84,7 @@ struct _GvEnginePrivate {
 	gchar         *pipeline_string;
 	/* Retry on error with a delay */
 	guint          error_count;
-	guint          when_timeout_start_playback_id;
+	guint          start_playback_timeout_id;
 };
 
 typedef struct _GvEnginePrivate GvEnginePrivate;
@@ -166,47 +167,6 @@ get_gst_state(GstElement *playbin)
 }
 #endif
 
-static GvMetadata *
-taglist_to_metadata(GstTagList *taglist)
-{
-	GvMetadata *metadata;
-	const gchar *artist = NULL;
-	const gchar *title = NULL;
-	const gchar *album = NULL;
-	const gchar *genre = NULL;
-	const gchar *comment = NULL;
-	GDate *date = NULL;
-	gchar *year = NULL;
-
-	/* Get info from taglist */
-	gst_tag_list_peek_string_index(taglist, GST_TAG_ARTIST, 0, &artist);
-	gst_tag_list_peek_string_index(taglist, GST_TAG_TITLE, 0, &title);
-	gst_tag_list_peek_string_index(taglist, GST_TAG_ALBUM, 0, &album);
-	gst_tag_list_peek_string_index(taglist, GST_TAG_GENRE, 0, &genre);
-	gst_tag_list_peek_string_index(taglist, GST_TAG_COMMENT, 0, &comment);
-	gst_tag_list_get_date_index   (taglist, GST_TAG_DATE, 0, &date);
-	if (date && g_date_valid(date))
-		year = g_strdup_printf("%d", g_date_get_year(date));
-
-	/* Create new metadata object */
-	metadata = g_object_new(GV_TYPE_METADATA,
-	                        "artist", artist,
-	                        "title", title,
-	                        "album", album,
-	                        "genre", genre,
-	                        "year", year,
-	                        "comment", comment,
-	                        NULL);
-
-	/* Freedom for the braves */
-	g_free(year);
-	if (date)
-		g_date_free(date);
-
-	return metadata;
-}
-
-
 /*
  * Private methods
  */
@@ -286,24 +246,6 @@ gv_engine_set_state(GvEngine *self, GvEngineState state)
 	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_STATE]);
 }
 
-guint
-gv_engine_get_bitrate(GvEngine *self)
-{
-	return self->priv->bitrate;
-}
-
-static void
-gv_engine_set_bitrate(GvEngine *self, guint bitrate)
-{
-	GvEnginePrivate *priv = self->priv;
-
-	if (priv->bitrate == bitrate)
-		return;
-
-	priv->bitrate = bitrate;
-	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_BITRATE]);
-}
-
 GvStation *
 gv_engine_get_station(GvEngine *self)
 {
@@ -319,6 +261,60 @@ gv_engine_set_station(GvEngine *self, GvStation *station)
 		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_STATION]);
 }
 
+GvStreaminfo *
+gv_engine_get_streaminfo(GvEngine *self)
+{
+	return self->priv->streaminfo;
+}
+
+static void
+gv_engine_update_streaminfo_from_tags(GvEngine *self, GstTagList *taglist)
+{
+	GvEnginePrivate *priv = self->priv;
+	gboolean notify = FALSE;
+
+	if (priv->streaminfo == NULL) {
+		priv->streaminfo = gv_streaminfo_new();
+		notify = TRUE;
+	}
+
+	if (gv_streaminfo_update_from_gst_taglist(priv->streaminfo, taglist) == TRUE)
+		notify = TRUE;
+
+	if (notify)
+		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_STREAMINFO]);
+}
+
+static void
+gv_engine_update_streaminfo_from_audio_pad(GvEngine *self, GstPad *pad)
+{
+	GvEnginePrivate *priv = self->priv;
+	gboolean notify = FALSE;
+
+	if (priv->streaminfo == NULL) {
+		priv->streaminfo = gv_streaminfo_new();
+		notify = TRUE;
+	}
+
+	if (gv_streaminfo_update_from_gst_audio_pad(priv->streaminfo, pad) == TRUE)
+		notify = TRUE;
+
+	if (notify)
+		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_STREAMINFO]);
+}
+
+static void
+gv_engine_unset_streaminfo(GvEngine *self)
+{
+	GvEnginePrivate *priv = self->priv;
+
+	if (priv->streaminfo == NULL)
+		return;
+
+	gv_clear_streaminfo(&priv->streaminfo);
+	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_STREAMINFO]);
+}
+
 GvMetadata *
 gv_engine_get_metadata(GvEngine *self)
 {
@@ -326,20 +322,39 @@ gv_engine_get_metadata(GvEngine *self)
 }
 
 static void
-gv_engine_set_metadata(GvEngine *self, GvMetadata *metadata)
+gv_engine_update_metadata_from_tags(GvEngine *self, GstTagList *taglist)
+{
+	GvEnginePrivate *priv = self->priv;
+	gboolean notify = FALSE;
+
+	if (priv->metadata == NULL)
+		priv->metadata = gv_metadata_new();
+
+	notify = gv_metadata_update_from_gst_taglist(priv->metadata, taglist);
+
+	/* We don't want empty metadata objects, it makes life complicated
+	 * for consumers who will forever need to write this kind of code:
+	 *
+	 *     if (ptr && !gv_metadata_is_empty(ptr))
+	 *         ...
+	 */
+	if (gv_metadata_is_empty(priv->metadata))
+		gv_clear_metadata(&priv->metadata);
+
+	if (notify)
+		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_METADATA]);
+}
+
+static void
+gv_engine_unset_metadata(GvEngine *self)
 {
 	GvEnginePrivate *priv = self->priv;
 
-	/* Compare content */
-	if (priv->metadata && metadata &&
-	    gv_metadata_is_equal(priv->metadata, metadata)) {
-		DEBUG("Metadata identical, ignoring...");
+	if (priv->metadata == NULL)
 		return;
-	}
 
-	/* Assign */
-	if (g_set_object(&priv->metadata, metadata))
-		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_METADATA]);
+	gv_clear_metadata(&priv->metadata);
+	g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_METADATA]);
 }
 
 guint
@@ -448,14 +463,14 @@ gv_engine_get_property(GObject    *object,
 	case PROP_STATE:
 		g_value_set_enum(value, gv_engine_get_state(self));
 		break;
-	case PROP_BITRATE:
-		g_value_set_uint(value, gv_engine_get_bitrate(self));
-		break;
 	case PROP_STATION:
 		g_value_set_object(value, gv_engine_get_station(self));
 		break;
+	case PROP_STREAMINFO:
+		g_value_set_boxed(value, gv_engine_get_streaminfo(self));
+		break;
 	case PROP_METADATA:
-		g_value_set_object(value, gv_engine_get_metadata(self));
+		g_value_set_boxed(value, gv_engine_get_metadata(self));
 		break;
 	case PROP_VOLUME:
 		g_value_set_uint(value, gv_engine_get_volume(self));
@@ -526,10 +541,7 @@ gv_engine_play(GvEngine *self, GvStation *station)
 
 	/* Cleanup error handling */
 	priv->error_count = 0;
-	if (priv->when_timeout_start_playback_id) {
-		g_source_remove(priv->when_timeout_start_playback_id);
-		priv->when_timeout_start_playback_id = 0;
-	}
+	g_clear_handle_id(&priv->start_playback_timeout_id, g_source_remove);
 
 	/* Set station */
 	gv_engine_set_station(self, station);
@@ -539,8 +551,7 @@ gv_engine_play(GvEngine *self, GvStation *station)
 	 * > State changes to GST_STATE_READY or GST_STATE_NULL never return
 	 * > GST_STATE_CHANGE_ASYNC.
 	 *
-	 * https://gstreamer.freedesktop.org/data/doc/gstreamer/head/gstreamer/html/
-	 * GstElement.html#gst-element-set-state
+	 * https://gstreamer.freedesktop.org/documentation/gstreamer/gstelement.html#gst_element_set_state
 	 */
 
 	/* Ensure playback is stopped */
@@ -566,16 +577,13 @@ gv_engine_stop(GvEngine *self)
 
 	/* Cleanup error handling */
 	priv->error_count = 0;
-	if (priv->when_timeout_start_playback_id) {
-		g_source_remove(priv->when_timeout_start_playback_id);
-		priv->when_timeout_start_playback_id = 0;
-	}
+	g_clear_handle_id(&priv->start_playback_timeout_id, g_source_remove);
 
 	/* Radical way to stop: set state to NULL */
 	set_gst_state(priv->playbin, GST_STATE_NULL);
 	gv_engine_set_state(self, GV_ENGINE_STATE_STOPPED);
-	gv_engine_set_bitrate(self, 0);
-	gv_engine_set_metadata(self, NULL);
+	gv_engine_unset_streaminfo(self);
+	gv_engine_unset_metadata(self);
 }
 
 GvEngine *
@@ -588,6 +596,24 @@ gv_engine_new(void)
  * GStreamer playbin signal handlers
  */
 
+static void
+on_playbin_audio_pad_notify_caps(GstPad *pad,
+		GParamSpec *pspec,
+		GvEngine *self)
+{
+	const gchar *property_name = g_param_spec_get_name(pspec);
+	GstElement *playbin = self->priv->playbin;
+	GstMessage *msg;
+
+	/* WARNING! We're likely in the GStreamer streaming thread! */
+
+	TRACE("%p, %s, %p", pad, property_name, self);
+
+	msg = gst_message_new_application(GST_OBJECT(playbin),
+			gst_structure_new_empty("audio-caps-changed"));
+	gst_element_post_message(playbin, msg);
+}
+
 static void
 on_playbin_source_setup(GstElement *playbin G_GNUC_UNUSED,
                         GstElement *source,
@@ -598,6 +624,8 @@ on_playbin_source_setup(GstElement *playbin G_GNUC_UNUSED,
 	static gchar *default_user_agent;
 	const gchar *user_agent;
 
+	/* WARNING! We're likely in the GStreamer streaming thread! */
+
 	if (default_user_agent == NULL) {
 		gchar *gst_version;
 
@@ -637,7 +665,7 @@ when_timeout_start_playback(gpointer data)
 		gv_engine_set_state(self, GV_ENGINE_STATE_CONNECTING);
 	}
 
-	priv->when_timeout_start_playback_id = 0;
+	priv->start_playback_timeout_id = 0;
 	return G_SOURCE_REMOVE;
 }
 
@@ -654,7 +682,7 @@ retry_playback(GvEngine *self)
 	 * the delay with the failure count.
 	 */
 
-	if (priv->when_timeout_start_playback_id)
+	if (priv->start_playback_timeout_id != 0)
 		return;
 
 	g_assert(priv->error_count > 0);
@@ -663,18 +691,18 @@ retry_playback(GvEngine *self)
 		delay = 10;
 
 	INFO("Restarting playback in %u seconds", delay);
-	priv->when_timeout_start_playback_id =
+	priv->start_playback_timeout_id =
 	        g_timeout_add_seconds(delay, when_timeout_start_playback, self);
 }
 
-static gboolean
+static void
 on_bus_message_eos(GstBus *bus G_GNUC_UNUSED, GstMessage *msg G_GNUC_UNUSED, GvEngine *self)
 {
 	GvEnginePrivate *priv = self->priv;
 
-	priv->error_count++;
+	INFO("Gst bus EOS message");
 
-	WARNING("Gst eos message");
+	priv->error_count++;
 
 	/* Stop immediately otherwise gst keeps on spitting errors */
 	set_gst_state(priv->playbin, GST_STATE_NULL);
@@ -685,29 +713,27 @@ on_bus_message_eos(GstBus *bus G_GNUC_UNUSED, GstMessage *msg G_GNUC_UNUSED, GvE
 
 	/* Emit an error */
 	//gv_errorable_emit_error(GV_ERRORABLE(self), "%s", _("End of stream"));
-
-	return TRUE;
 }
 
-static gboolean
+static void
 on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 {
 	GvEnginePrivate *priv = self->priv;
-	GError *error;
+	GError *err;
 	gchar  *debug;
 
 	priv->error_count++;
 
 	/* Parse message */
-	gst_message_parse_error(msg, &error, &debug);
+	gst_message_parse_error(msg, &err, &debug);
 
 	/* Display error */
 	WARNING("Gst bus error msg: %s:%d: %s",
-	        g_quark_to_string(error->domain), error->code, error->message);
+	        g_quark_to_string(err->domain), err->code, err->message);
 	WARNING("Gst bus error debug: %s", debug);
 
 	/* Cleanup */
-	g_error_free(error);
+	g_error_free(err);
 	g_free(debug);
 
 	/* Stop immediately otherwise gst keeps on spitting errors */
@@ -718,9 +744,7 @@ on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 		retry_playback(self);
 
 	/* Emit an error signal */
-	//gv_errorable_emit_error(GV_ERRORABLE(self), "GStreamer error: %s", error->message);
-
-	return TRUE;
+	//gv_errorable_emit_error(GV_ERRORABLE(self), "GStreamer error: %s", err->message);
 
 	/* Here are some gst error messages that I've dealt with so far.
 	 *
@@ -774,7 +798,7 @@ on_bus_message_error(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 	 */
 }
 
-static gboolean
+static void
 on_bus_message_warning(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self G_GNUC_UNUSED)
 {
 	GError *warning;
@@ -791,11 +815,9 @@ on_bus_message_warning(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *sel
 	/* Cleanup */
 	g_error_free(warning);
 	g_free(debug);
-
-	return TRUE;
 }
 
-static gboolean
+static void
 on_bus_message_info(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self G_GNUC_UNUSED)
 {
 	GError *info;
@@ -812,8 +834,6 @@ on_bus_message_info(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self G
 	/* Cleanup */
 	g_error_free(info);
 	g_free(debug);
-
-	return TRUE;
 }
 
 #ifdef DEBUG_GST_TAGS
@@ -863,75 +883,28 @@ tag_list_foreach_dump(const GstTagList *list, const gchar *tag,
 }
 #endif /* DEBUG_GST_TAGS */
 
-static gboolean
+static void
 on_bus_message_tag(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 {
-	GvEnginePrivate *priv = self->priv;
-	GvMetadata *metadata;
 	GstTagList *taglist = NULL;
-	const gchar *tag_title = NULL;
 
-	TRACE("... %s, %p", GST_OBJECT_NAME(msg->src), self);
+	TRACE("... %s, %p", GST_MESSAGE_SRC_NAME(msg), self);
 
-	/* Parse message */
 	gst_message_parse_tag(msg, &taglist);
 
 #ifdef DEBUG_GST_TAGS
-	/* Dumping may be needed to debug */
-	DEBUG("-- Dumping taglist...");
+	DEBUG("->>- GST TAGLIST DUMP ->>-->>-->>-->>-->>-->>-->>-->>----");
 	gst_tag_list_foreach(taglist, (GstTagForeachFunc) tag_list_foreach_dump, NULL);
-	DEBUG("-- Done --");
+	DEBUG("-<<--<<--<<--<<--<<--<<--<<--<<--<<--<<--<<--<<--<<--<<--");
 #endif /* DEBUG_GST_TAGS */
 
-	/* Get info on stream */
-	{
-		GvStation *station = priv->station;
-		const gchar *audio_codec = NULL;
-		guint bitrate = 0;
-		guint nominal_bitrate = 0;
+	gv_engine_update_streaminfo_from_tags(self, taglist);
+	gv_engine_update_metadata_from_tags(self, taglist);
 
-		gst_tag_list_peek_string_index(taglist, GST_TAG_AUDIO_CODEC, 0, &audio_codec);
-		gst_tag_list_get_uint_index(taglist, GST_TAG_BITRATE, 0, &bitrate);
-		bitrate /= 1000;    // kilobits per second
-		gst_tag_list_get_uint_index(taglist, GST_TAG_NOMINAL_BITRATE, 0, &nominal_bitrate);
-		nominal_bitrate /= 1000;    // kilobits per second
-
-		gv_engine_set_bitrate(self, bitrate);
-
-		if (station != NULL) {
-			if (audio_codec)
-				gv_station_set_codec(station, audio_codec);
-			if (nominal_bitrate > 0)
-				gv_station_set_nominal_bitrate(station, nominal_bitrate);
-		}
-	}
-
-	/* Tags can be quite noisy, so let's cut it short.
-	 * From my experience, 'title' is the most important field,
-	 * and it's likely that it's the only one filled, containing
-	 * everything (title, artist and more).
-	 * So, we require this field to be filled. If it's not, this
-	 * metadata is considered to be noise, and discarded.
-	 */
-	gst_tag_list_peek_string_index(taglist, GST_TAG_TITLE, 0, &tag_title);
-	if (tag_title == NULL) {
-		DEBUG("No 'title' field in the tag list, discarding");
-		goto taglist_unref;
-	}
-
-	/* Turn taglist into metadata and assign it */
-	metadata = taglist_to_metadata(taglist);
-	gv_engine_set_metadata(self, metadata);
-	g_object_unref(metadata);
-
-taglist_unref:
-	/* Unref taglist */
 	gst_tag_list_unref(taglist);
-
-	return TRUE;
 }
 
-static gboolean
+static void
 on_bus_message_buffering(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *self)
 {
 	GvEnginePrivate *priv = self->priv;
@@ -939,8 +912,7 @@ on_bus_message_buffering(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *s
 	gint percent = 0;
 
 	/* Handle the buffering message. Some documentation:
-	 * https://gstreamer.freedesktop.org/data/doc/gstreamer/head/gstreamer/html/
-	 * GstMessage.html#gst-message-new-buffering
+	 * https://gstreamer.freedesktop.org/documentation/gstreamer/gstmessage.html#gst_message_new_buffering
 	 */
 
 	/* Parse message */
@@ -960,10 +932,10 @@ on_bus_message_buffering(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *s
 		break;
 
 	case GV_ENGINE_STATE_CONNECTING:
-		/* We successfully connected ! */
+		/* We successfully connected! */
 		gv_engine_set_state(self, GV_ENGINE_STATE_BUFFERING);
 
-		/* NO BREAK HERE !
+		/* NO BREAK HERE!
 		 * This is to handle the (very special) case where the first
 		 * buffering message received is already 100%. I'm not sure this
 		 * can happen, but it doesn't hurt to be ready.
@@ -1004,11 +976,9 @@ on_bus_message_buffering(GstBus *bus G_GNUC_UNUSED, GstMessage *msg, GvEngine *s
 	default:
 		WARNING("Unhandled engine state %d", priv->state);
 	}
-
-	return TRUE;
 }
 
-static gboolean
+static void
 on_bus_message_state_changed(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
                              GvEngine *self G_GNUC_UNUSED)
 {
@@ -1026,8 +996,50 @@ on_bus_message_state_changed(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
 #else
 	(void) msg;
 #endif
+}
 
-	return TRUE;
+static void
+on_bus_message_stream_start(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
+                            GvEngine *self)
+{
+	GvEnginePrivate *priv = self->priv;
+	GstElement *playbin = priv->playbin;
+	GstPad *pad = NULL;
+
+	TRACE("... %s, %p", GST_MESSAGE_SRC_NAME(msg), self);
+	DEBUG("Stream started");
+
+	g_signal_emit_by_name(playbin, "get-audio-pad", 0, &pad);
+	gv_engine_update_streaminfo_from_audio_pad(self, pad);
+
+	if (pad != NULL)
+		g_signal_connect_object(pad, "notify::caps",
+				G_CALLBACK(on_playbin_audio_pad_notify_caps), self, 0);
+}
+
+static void
+on_bus_message_application(GstBus *bus G_GNUC_UNUSED, GstMessage *msg,
+                           GvEngine *self)
+{
+	GvEnginePrivate *priv = self->priv;
+	const GstStructure *s;
+	const gchar *msg_name;
+
+	TRACE("... %s, %p", GST_MESSAGE_SRC_NAME(msg), self);
+
+	s = gst_message_get_structure(msg);
+	msg_name = gst_structure_get_name(s);
+	g_return_if_fail(msg_name != NULL);
+
+	if (!g_strcmp0(msg_name, "audio-caps-changed")) {
+		GstElement *playbin = priv->playbin;
+		GstPad *pad = NULL;
+
+		g_signal_emit_by_name(playbin, "get-audio-pad", 0, &pad);
+		gv_engine_update_streaminfo_from_audio_pad(self, pad);
+	} else {
+		WARNING("Unhandled application message %s", msg_name);
+	}
 }
 
 /*
@@ -1043,8 +1055,7 @@ gv_engine_finalize(GObject *object)
 	TRACE("%p", object);
 
 	/* Remove pending operations */
-	if (priv->when_timeout_start_playback_id)
-		g_source_remove(priv->when_timeout_start_playback_id);
+	g_clear_handle_id(&priv->start_playback_timeout_id, g_source_remove);
 
 	/* Stop playback */
 	set_gst_state(priv->playbin, GST_STATE_NULL);
@@ -1058,7 +1069,8 @@ gv_engine_finalize(GObject *object)
 
 	/* Unref metadata */
 	g_clear_object(&priv->station);
-	g_clear_object(&priv->metadata);
+	gv_clear_streaminfo(&priv->streaminfo);
+	gv_clear_metadata(&priv->metadata);
 
 	/* Free resources */
 	g_free(priv->pipeline_string);
@@ -1090,14 +1102,15 @@ gv_engine_constructed(GObject *object)
 	g_assert_nonnull(playbin);
 	priv->playbin = g_object_ref_sink(playbin);
 
-	/* Connect playbin signal handlers */
-	g_signal_connect_object(playbin, "source-setup", G_CALLBACK(on_playbin_source_setup), self, 0);
-
 	/* Disable video - returns floating ref */
 	fakesink = gst_element_factory_make("fakesink", "fakesink");
 	g_assert_nonnull(fakesink);
 	g_object_set(playbin, "video-sink", fakesink, NULL);
 
+	/* Connect playbin signal handlers */
+	g_signal_connect_object(playbin, "source-setup",
+		G_CALLBACK(on_playbin_source_setup), self, 0);
+
 	/* Get a reference to the message bus - returns full ref */
 	bus = gst_element_get_bus(playbin);
 	g_assert_nonnull(bus);
@@ -1121,6 +1134,10 @@ gv_engine_constructed(GObject *object)
 	                        G_CALLBACK(on_bus_message_buffering), self, 0);
 	g_signal_connect_object(bus, "message::state-changed",
 	                        G_CALLBACK(on_bus_message_state_changed), self, 0);
+	g_signal_connect_object(bus, "message::stream-start",
+	                        G_CALLBACK(on_bus_message_stream_start), self, 0);
+	g_signal_connect_object(bus, "message::application",
+	                        G_CALLBACK(on_bus_message_application), self, 0);
 
 	/* Chain up */
 	G_OBJECT_CHAINUP_CONSTRUCTED(gv_engine, object);
@@ -1154,41 +1171,41 @@ gv_engine_class_init(GvEngineClass *class)
 	        g_param_spec_enum("state", "Playback state", NULL,
 	                          GV_TYPE_ENGINE_STATE,
 	                          GV_ENGINE_STATE_STOPPED,
-	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
-
-	properties[PROP_BITRATE] =
-	        g_param_spec_uint("bitrate", "Bitrate", NULL,
-	                          0, G_MAXUINT, 0,
-	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	                          GV_PARAM_READABLE);
 
 	properties[PROP_STATION] =
 	        g_param_spec_object("station", "Current station", NULL,
 	                            GV_TYPE_STATION,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	                            GV_PARAM_READABLE);
+
+	properties[PROP_STREAMINFO] =
+	        g_param_spec_boxed("streaminfo", "Stream information", NULL,
+	                            GV_TYPE_STREAMINFO,
+	                            GV_PARAM_READABLE);
 
 	properties[PROP_METADATA] =
-	        g_param_spec_object("metadata", "Current metadata", NULL,
-	                            GV_TYPE_METADATA,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	        g_param_spec_boxed("metadata", "Stream metadata", NULL,
+	                           GV_TYPE_METADATA,
+	                           GV_PARAM_READABLE);
 
 	properties[PROP_VOLUME] =
 	        g_param_spec_uint("volume", "Volume in percent", NULL,
 	                          0, 100, DEFAULT_VOLUME,
-	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                          GV_PARAM_READWRITE);
 
 	properties[PROP_MUTE] =
 	        g_param_spec_boolean("mute", "Mute", NULL,
 	                             FALSE,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                             GV_PARAM_READWRITE);
 
 	properties[PROP_PIPELINE_ENABLED] =
 	        g_param_spec_boolean("pipeline-enabled", "Enable custom pipeline", NULL,
 	                             FALSE,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                             GV_PARAM_READWRITE);
 
 	properties[PROP_PIPELINE_STRING] =
 	        g_param_spec_string("pipeline-string", "Custom pipeline string", NULL, NULL,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                            GV_PARAM_READWRITE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 }
