@@ -24,14 +24,15 @@
 #include <glib-object.h>
 #include <gio/gio.h>
 
-#include "framework/glib-object-additions.h"
-#include "framework/gv-framework.h"
+#include "base/glib-object-additions.h"
+#include "base/gv-base.h"
 #include "core/gv-engine.h"
 #include "core/gv-core-enum-types.h"
 #include "core/gv-core-internal.h"
 #include "core/gv-metadata.h"
 #include "core/gv-station.h"
 #include "core/gv-station-list.h"
+#include "core/gv-streaminfo.h"
 
 #include "core/gv-player.h"
 
@@ -52,7 +53,7 @@ enum {
 	PROP_ENGINE,
 	PROP_STATION_LIST,
 	/* Engine mirrored properties */
-	PROP_BITRATE,
+	PROP_STREAMINFO,
 	PROP_METADATA,
 	PROP_VOLUME,
 	PROP_MUTE,
@@ -155,8 +156,8 @@ on_engine_notify(GvEngine  *engine,
 
 	TRACE("%p, %s, %p", engine, property_name, self);
 
-	if (!g_strcmp0(property_name, "bitrate")) {
-		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_BITRATE]);
+	if (!g_strcmp0(property_name, "streaminfo")) {
+		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_STREAMINFO]);
 
 	} else if (!g_strcmp0(property_name, "metadata")) {
 		g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_METADATA]);
@@ -248,12 +249,12 @@ gv_player_set_station_list(GvPlayer *self, GvStationList *station_list)
  * We don't notify here. It's done in the engine notify handler instead.
  */
 
-guint
-gv_player_get_bitrate(GvPlayer *self)
+GvStreaminfo *
+gv_player_get_streaminfo(GvPlayer *self)
 {
 	GvEngine *engine = self->priv->engine;
 
-	return gv_engine_get_bitrate(engine);
+	return gv_engine_get_streaminfo(engine);
 }
 
 GvMetadata *
@@ -560,11 +561,11 @@ gv_player_get_property(GObject    *object,
 	TRACE_GET_PROPERTY(object, property_id, value, pspec);
 
 	switch (property_id) {
-	case PROP_BITRATE:
-		g_value_set_uint(value, gv_player_get_bitrate(self));
+	case PROP_STREAMINFO:
+		g_value_set_boxed(value, gv_player_get_streaminfo(self));
 		break;
 	case PROP_METADATA:
-		g_value_set_object(value, gv_player_get_metadata(self));
+		g_value_set_boxed(value, gv_player_get_metadata(self));
 		break;
 	case PROP_VOLUME:
 		g_value_set_uint(value, gv_player_get_volume(self));
@@ -941,93 +942,86 @@ gv_player_class_init(GvPlayerClass *class)
 	properties[PROP_ENGINE] =
 	        g_param_spec_object("engine", "Engine", NULL,
 	                            GV_TYPE_ENGINE,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_WRITABLE |
-	                            G_PARAM_CONSTRUCT_ONLY);
+	                            GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
 
 	properties[PROP_STATION_LIST] =
 	        g_param_spec_object("station-list", "Station list", NULL,
 	                            GV_TYPE_STATION_LIST,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_WRITABLE |
-	                            G_PARAM_CONSTRUCT_ONLY);
+	                            GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
 
 	/* Engine mirrored properties */
-	properties[PROP_BITRATE] =
-	        g_param_spec_uint("bitrate", "Bitrate", NULL,
-	                          0, G_MAXUINT, 0,
-	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	properties[PROP_STREAMINFO] =
+	        g_param_spec_boxed("streaminfo", "Stream information", NULL,
+	                           GV_TYPE_STREAMINFO,
+	                           GV_PARAM_READABLE);
+
+	properties[PROP_METADATA] =
+	        g_param_spec_boxed("metadata", "Current metadata", NULL,
+	                           GV_TYPE_METADATA,
+	                           GV_PARAM_READABLE);
 
 	properties[PROP_VOLUME] =
 	        g_param_spec_uint("volume", "Volume in percent", NULL,
 	                          0, 100, DEFAULT_VOLUME,
-	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                          GV_PARAM_READWRITE);
 
 	properties[PROP_MUTE] =
 	        g_param_spec_boolean("mute", "Mute", NULL,
 	                             DEFAULT_MUTE,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                             GV_PARAM_READWRITE);
 
 	properties[PROP_PIPELINE_ENABLED] =
 	        g_param_spec_boolean("pipeline-enabled", "Enable custom pipeline", NULL,
 	                             FALSE,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                             GV_PARAM_READWRITE);
 
 	properties[PROP_PIPELINE_STRING] =
 	        g_param_spec_string("pipeline-string", "Custom pipeline string", NULL,
 	                            NULL,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
-
-	properties[PROP_PIPELINE_STRING] =
-	        g_param_spec_string("pipeline-string", "Custom pipeline string", NULL,
-	                            NULL,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                            GV_PARAM_READWRITE);
 
 	/* Player properties */
 	properties[PROP_STATE] =
 	        g_param_spec_enum("state", "Playback state", NULL,
 	                          GV_TYPE_PLAYER_STATE,
 	                          GV_PLAYER_STATE_STOPPED,
-	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	                          GV_PARAM_READABLE);
 
 	properties[PROP_REPEAT] =
 	        g_param_spec_boolean("repeat", "Repeat", NULL,
 	                             DEFAULT_REPEAT,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                             GV_PARAM_READWRITE);
 
 	properties[PROP_SHUFFLE] =
 	        g_param_spec_boolean("shuffle", "Shuffle", NULL,
 	                             DEFAULT_SHUFFLE,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                             GV_PARAM_READWRITE);
 
 	properties[PROP_AUTOPLAY] =
 	        g_param_spec_boolean("autoplay", "Autoplay on startup", NULL,
 	                             DEFAULT_AUTOPLAY,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
-
-	properties[PROP_METADATA] =
-	        g_param_spec_object("metadata", "Current metadata", NULL,
-	                            GV_TYPE_METADATA,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	                             GV_PARAM_READWRITE);
 
 	properties[PROP_STATION] =
 	        g_param_spec_object("station", "Current station", NULL,
 	                            GV_TYPE_STATION,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                            GV_PARAM_READWRITE);
 
 	properties[PROP_STATION_URI] =
 	        g_param_spec_string("station-uri", "Current station URI",
 	                            "This is used only to save the current station in conf",
 	                            NULL,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                            GV_PARAM_READWRITE);
 
 	properties[PROP_PREV_STATION] =
 	        g_param_spec_object("prev", "Previous station", NULL,
 	                            GV_TYPE_STATION,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	                            GV_PARAM_READABLE);
 
 	properties[PROP_NEXT_STATION] =
 	        g_param_spec_object("next", "Next station", NULL,
 	                            GV_TYPE_STATION,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	                            GV_PARAM_READABLE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 }
