@@ -34,8 +34,8 @@
 #include <glib-object.h>
 #include <libsoup/soup.h>
 
-#include "framework/glib-object-additions.h"
-#include "framework/gv-framework.h"
+#include "base/glib-object-additions.h"
+#include "base/gv-base.h"
 
 #include "core/gv-playlist.h"
 
@@ -249,7 +249,7 @@ asx_parse_element_cb(GMarkupParseContext *context G_GNUC_UNUSED,
                      const gchar        **attribute_names,
                      const gchar        **attribute_values,
                      gpointer             user_data,
-                     GError             **error G_GNUC_UNUSED)
+                     GError             **err G_GNUC_UNUSED)
 {
 	GSList **llink = (GSList **) user_data;
 	const gchar *href;
@@ -275,7 +275,7 @@ asx_parse_element_cb(GMarkupParseContext *context G_GNUC_UNUSED,
 
 static void
 asx_error_cb(GMarkupParseContext *context G_GNUC_UNUSED,
-             GError              *error   G_GNUC_UNUSED,
+             GError              *err   G_GNUC_UNUSED,
              gpointer             user_data)
 {
 	GSList **llink = (GSList **) user_data;
@@ -319,7 +319,7 @@ xspf_text_cb(GMarkupParseContext  *context,
              const gchar          *text,
              gsize                 text_len G_GNUC_UNUSED,
              gpointer              user_data,
-             GError              **error G_GNUC_UNUSED)
+             GError              **err G_GNUC_UNUSED)
 {
 	GSList **llink = (GSList **) user_data;
 	const gchar *element_name;
@@ -336,7 +336,7 @@ xspf_text_cb(GMarkupParseContext  *context,
 
 static void
 xspf_error_cb(GMarkupParseContext *context G_GNUC_UNUSED,
-              GError              *error   G_GNUC_UNUSED,
+              GError              *err   G_GNUC_UNUSED,
               gpointer             user_data)
 {
 	GSList **llink = (GSList **) user_data;
@@ -616,12 +616,11 @@ gv_playlist_class_init(GvPlaylistClass *class)
 
 	properties[PROP_URI] =
 	        g_param_spec_string("uri", "Uri", NULL, NULL,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE |
-	                            G_PARAM_CONSTRUCT_ONLY);
+	                            GV_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
 
 	properties[PROP_STREAM_LIST] =
 	        g_param_spec_pointer("stream-list", "Stream list", NULL,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	                             GV_PARAM_READABLE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 
