@@ -25,157 +25,14 @@
 #include <glib/gstdio.h>
 #include <glib-object.h>
 
-#include "framework/glib-object-additions.h"
-#include "framework/gv-framework.h"
+#include "base/glib-object-additions.h"
+#include "base/gv-base.h"
 
 #include "core/gv-station-list.h"
 
 // WISHED Try with a huge number of stations to see how it behaves.
 //        It might be slow. The implementation never tried to be fast.
 
-/*
- * FIP <https://www.fip.fr/>
- * Just the best radios you'll ever listen to.
- */
-
-#define FIP_STATIONS \
-        "<Station>" \
-        "  <name>FIP Paris</name>" \
-        "  <uri>https://direct.fipradio.fr/live/fip-midfi.mp3</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>FIP Rock</name>" \
-        "  <uri>https://direct.fipradio.fr/live/fip-webradio1.mp3</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>FIP Jazz</name>" \
-        "  <uri>https://direct.fipradio.fr/live/fip-webradio2.mp3</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>FIP Groove</name>" \
-        "  <uri>https://direct.fipradio.fr/live/fip-webradio3.mp3</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>FIP Monde</name>" \
-        "  <uri>https://direct.fipradio.fr/live/fip-webradio4.mp3</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>FIP Nouveautés</name>" \
-        "  <uri>https://direct.fipradio.fr/live/fip-webradio5.mp3</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>FIP Reggae</name>" \
-        "  <uri>https://direct.fipradio.fr/live/fip-webradio6.mp3</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>FIP Electro</name>" \
-        "  <uri>https://direct.fipradio.fr/live/fip-webradio8.mp3</uri>" \
-        "</Station>"
-
-/*
- * Nova <http://www.nova.fr/>
- * Another killer radio from France.
- */
-
-#define NOVA_STATIONS \
-        "<Station>" \
-        "  <name>Nova</name>" \
-        "  <uri>http://novazz.ice.infomaniak.ch/novazz-128.mp3</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>Nova Vintage</name>" \
-        "  <uri>http://nova-vnt.ice.infomaniak.ch/nova-vnt-128</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>Nova la Nuit</name>" \
-        "  <uri>http://nova-ln.ice.infomaniak.ch/nova-ln-128</uri>" \
-        "</Station>"
-
-/*
- * More of my favorite french radios.
- * - Grenouille <http://www.radiogrenouille.com/>
- * - PBB <http://www2.laurentgarnier.com/PBB.html>
- */
-
-#define FRENCH_STATIONS   \
-        "<Station>" \
-        "  <name>Radio Grenouille</name>" \
-        "  <uri>http://live.radiogrenouille.com/live</uri>" \
-        "</Station>" \
-	"<Station>" \
-	"  <name>Pedro Basement Broadcast</name>" \
-	"  <uri>http://pbb.laurentgarnier.com:8000/pbb128</uri> " \
-	"</Station>"
-
-/*
- * Broken stations.
- */
-
-#define TESTING_BROKEN_STATIONS   \
-        "<Station>" \
-        "  <name>Broken - FIP old url</name>" \
-        "  <uri>http://audio.scdn.arkena.com/11016/fip-midfi128.mp3</uri>" \
-        "</Station>"
-
-/*
- * Various playlist formats.
- * - Swiss Internet Radio (Public Domain Radio) <http://www.swissradio.ch/>
- */
-
-#define TESTING_PLAYLIST_STATIONS         \
-        "<Station>" \
-        "  <name>M3U - Swiss Internet Radio Classical</name>" \
-        "  <uri>http://www.swissradio.ch/streams/6034.m3u</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>ASX - Swiss Internet Radio Classical</name>" \
-        "  <uri>http://www.swissradio.ch/streams/6034.asx</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <name>RAM - Swiss Internet Radio Classical</name>" \
-        "  <uri>http://www.swissradio.ch/streams/6034.ram</uri>" \
-        "</Station>"
-
-/*
- * More radios, for testing.
- */
-
-#define TESTING_MORE_STATIONS     \
-        "<Station>" \
-        "  <uri>http://www.netradio.fr:8000/A0RemzouilleRadio.xspf</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <uri>http://player.100p.nl/livestream.asx</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <uri>http://vt-net.org/WebRadio/live/8056.m3u</uri>" \
-        "</Station>" \
-        "<Station>" \
-        "  <uri>'http://www.neradio.se/listen.pls</uri>" \
-        "</Station>"
-
-/*
- * Default station list, loaded if no station list file is found
- */
-
-#define DEFAULT_STATIONS_DEV \
-        FIP_STATIONS \
-	NOVA_STATIONS \
-        FRENCH_STATIONS \
-        TESTING_BROKEN_STATIONS \
-        TESTING_PLAYLIST_STATIONS \
-        TESTING_MORE_STATIONS
-
-#define DEFAULT_STATIONS_PROD \
-        FIP_STATIONS \
-	NOVA_STATIONS \
-        FRENCH_STATIONS
-
-#define DEFAULT_STATION_LIST \
-        "<Stations>" \
-        DEFAULT_STATIONS_PROD \
-        "</Stations>"
-
 /*
  * More defines...
  */
@@ -191,6 +48,8 @@ enum {
 	/* Reserved */
 	PROP_0,
 	/* Properties */
+	PROP_DEFAULT_STATIONS,
+	PROP_LOAD_PATHS,
 	PROP_LOAD_PATH,
 	PROP_SAVE_PATH,
 	/* Number of properties */
@@ -220,13 +79,13 @@ static guint signals[SIGNAL_N];
  */
 
 struct _GvStationListPrivate {
+	gchar  *default_stations;
 	/* Paths */
-	gchar **default_load_paths;
-	gchar  *default_save_path;
+	gchar **load_paths;
 	gchar  *load_path;
 	gchar  *save_path;
 	/* Timeout id, > 0 if a save operation is scheduled */
-	guint   save_source_id;
+	guint   save_timeout_id;
 	/* Set to true during object finalization */
 	gboolean finalization;
 	/* Ordered list of stations */
@@ -260,6 +119,45 @@ copy_func_object_ref(gconstpointer src, gpointer data G_GNUC_UNUSED)
 	return g_object_ref((gpointer) src);
 }
 
+/*
+ * Paths helpers
+ */
+
+static gchar **
+make_station_list_load_paths(const gchar *filename)
+{
+	const gchar *const *system_dirs;
+	const gchar *user_dir;
+	guint i, n_dirs;
+	gchar **paths;
+
+	user_dir = gv_get_app_user_data_dir();
+	system_dirs = gv_get_app_system_data_dirs();
+	n_dirs = g_strv_length((gchar **) system_dirs) + 1;
+
+	paths = g_malloc0_n(n_dirs + 1, sizeof(gchar *));
+	paths[0] = g_build_filename(user_dir, filename, NULL);
+	for (i = 1; i < n_dirs; i++) {
+		const gchar *dir;
+		dir = system_dirs[i - 1];
+		paths[i] = g_build_filename(dir, filename, NULL);
+	}
+
+	return paths;
+}
+
+static gchar *
+make_station_list_save_path(const gchar *filename)
+{
+	const gchar *user_dir;
+	gchar *path;
+
+	user_dir = gv_get_app_user_data_dir();
+	path = g_build_filename(user_dir, filename, NULL);
+
+	return path;
+}
+
 /*
  * Markup handling
  */
@@ -281,7 +179,7 @@ markup_on_text(GMarkupParseContext  *context G_GNUC_UNUSED,
                const gchar          *text,
                gsize                 text_len G_GNUC_UNUSED,
                gpointer              user_data,
-               GError              **error G_GNUC_UNUSED)
+               GError              **err G_GNUC_UNUSED)
 {
 	GvMarkupParsing *parsing = user_data;
 
@@ -303,7 +201,7 @@ static void
 markup_on_end_element(GMarkupParseContext  *context G_GNUC_UNUSED,
                       const gchar          *element_name G_GNUC_UNUSED,
                       gpointer              user_data,
-                      GError              **error G_GNUC_UNUSED)
+                      GError              **err G_GNUC_UNUSED)
 {
 	GvMarkupParsing *parsing = user_data;
 	GvStation *station;
@@ -345,7 +243,7 @@ markup_on_start_element(GMarkupParseContext  *context G_GNUC_UNUSED,
                         const gchar         **attribute_names G_GNUC_UNUSED,
                         const gchar         **attribute_values G_GNUC_UNUSED,
                         gpointer              user_data,
-                        GError              **error G_GNUC_UNUSED)
+                        GError              **err G_GNUC_UNUSED)
 {
 	GvMarkupParsing *parsing = user_data;
 
@@ -387,7 +285,7 @@ markup_on_start_element(GMarkupParseContext  *context G_GNUC_UNUSED,
 
 static void
 markup_on_error(GMarkupParseContext *context G_GNUC_UNUSED,
-                GError              *error   G_GNUC_UNUSED,
+                GError              *err   G_GNUC_UNUSED,
                 gpointer             user_data)
 {
 	GvMarkupParsing *parsing = user_data;
@@ -516,28 +414,28 @@ print_markup(GList *list, gchar **markup, GError **err)
  */
 
 static gboolean
-load_station_list_from_string(const gchar *text, GList **list, GError **error)
+load_station_list_from_string(const gchar *text, GList **list, GError **err)
 {
-	return parse_markup(text, list, error);
+	return parse_markup(text, list, err);
 }
 
 static gboolean
-load_station_list_from_file(const gchar *path, GList **list, GError **error)
+load_station_list_from_file(const gchar *path, GList **list, GError **err)
 {
 	gchar *text = NULL;
 	gboolean ret;
 
-	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
+	g_return_val_if_fail(err == NULL || *err == NULL, FALSE);
 
-	ret = g_file_get_contents(path, &text, NULL, error);
+	ret = g_file_get_contents(path, &text, NULL, err);
 	if (ret == FALSE) {
-		g_assert (error == NULL || *error != NULL);
+		g_assert (err == NULL || *err != NULL);
 		goto end;
 	}
 
-	ret = load_station_list_from_string(text, list, error);
+	ret = load_station_list_from_string(text, list, err);
 	if (ret == FALSE) {
-		g_assert(error == NULL || *error != NULL);
+		g_assert(err == NULL || *err != NULL);
 		goto end;
 	}
 
@@ -547,23 +445,23 @@ end:
 }
 
 static gboolean
-save_station_list_to_string(GList *list, gchar **text, GError **error)
+save_station_list_to_string(GList *list, gchar **text, GError **err)
 {
-	return print_markup(list, text, error);
+	return print_markup(list, text, err);
 }
 
 static gboolean
-save_station_list_to_file(GList *list, const gchar *path, GError **error)
+save_station_list_to_file(GList *list, const gchar *path, GError **err)
 {
 	gboolean ret;
 	gchar *text = NULL;
 	gchar *dirname = NULL;
 
-	g_return_val_if_fail(error == NULL || *error == NULL, FALSE);
+	g_return_val_if_fail(err == NULL || *err == NULL, FALSE);
 
-	ret = save_station_list_to_string(list, &text, error);
+	ret = save_station_list_to_string(list, &text, err);
 	if (ret == FALSE) {
-		g_assert(error == NULL || *error != NULL);
+		g_assert(err == NULL || *err != NULL);
 		goto end;
 	}
 
@@ -580,16 +478,16 @@ save_station_list_to_file(GList *list, const gchar *path, GError **error)
 
 	dirname = g_path_get_dirname(path);
 	if (g_mkdir_with_parents(dirname, S_IRWXU) != 0) {
-		g_set_error(error, G_FILE_ERROR,
+		g_set_error(err, G_FILE_ERROR,
 		            g_file_error_from_errno(errno),
 		            "Failed to make directory: %s", g_strerror(errno));
 		ret = FALSE;
 		goto end;
 	}
 
-	ret = g_file_set_contents(path, text, -1, error);
+	ret = g_file_set_contents(path, text, -1, err);
 	if (ret == FALSE) {
-		g_assert(error == NULL || *error != NULL);
+		g_assert(err == NULL || *err != NULL);
 		goto end;
 	}
 
@@ -599,43 +497,6 @@ end:
 	return ret;
 }
 
-static void
-relocate_station_list_file_for_4_1(const gchar *new_file)
-{
-	const gchar *user_config_dir;
-	gchar *old_file = NULL;
-	gchar *dirname = NULL;
-
-	user_config_dir = gv_get_app_user_config_dir();
-	old_file = g_build_filename(user_config_dir, "stations", NULL);
-
-	if (!g_file_test(old_file, G_FILE_TEST_EXISTS))
-		goto cleanup;
-
-	INFO("Station list migration: '%s' > '%s'", old_file, new_file);
-
-	dirname = g_path_get_dirname(new_file);
-	if (g_mkdir_with_parents(dirname, S_IRWXU) != 0) {
-		WARNING("Failed to make directory '%s': %s",
-			dirname, strerror(errno));
-		goto cleanup;
-	}
-	g_free(dirname);
-
-	if (g_rename(old_file, new_file) != 0) {
-		WARNING("Failed to rename file '%s' to '%s': %s",
-			old_file, new_file, strerror(errno));
-		goto cleanup;
-	}
-
-	dirname = g_path_get_dirname(old_file);
-	g_rmdir(dirname);
-
- cleanup:
-	g_free(dirname);
-	g_free(old_file);
-}
-
 /*
  * Iterator implementation
  */
@@ -778,7 +639,7 @@ when_timeout_save_station_list(gpointer data)
 
 	gv_station_list_save(self);
 
-	priv->save_source_id = 0;
+	priv->save_timeout_id = 0;
 
 	return G_SOURCE_REMOVE;
 }
@@ -788,10 +649,8 @@ gv_station_list_save_delayed(GvStationList *self)
 {
 	GvStationListPrivate *priv = self->priv;
 
-	if (priv->save_source_id > 0)
-		g_source_remove(priv->save_source_id);
-
-	priv->save_source_id =
+	g_clear_handle_id(&priv->save_timeout_id, g_source_remove);
+	priv->save_timeout_id =
 	        g_timeout_add_seconds(SAVE_DELAY, when_timeout_save_station_list, self);
 }
 
@@ -818,6 +677,26 @@ on_station_notify(GvStation     *station,
  * Property accessors
  */
 
+static void
+gv_station_list_set_default_stations(GvStationList *self, const gchar *stations)
+{
+	GvStationListPrivate *priv = self->priv;
+
+	/* This is a construct-only property */
+	g_assert_null(priv->default_stations);
+	priv->default_stations = g_strdup(stations);
+}
+
+static void
+gv_station_list_set_load_paths(GvStationList *self, const gchar * const *paths)
+{
+	GvStationListPrivate *priv = self->priv;
+
+	/* This is a construct-only property */
+	g_assert_null(priv->load_paths);
+	priv->load_paths = g_strdupv((gchar **) paths);
+}
+
 const gchar *
 gv_station_list_get_load_path(GvStationList *self)
 {
@@ -829,6 +708,9 @@ gv_station_list_set_load_path(GvStationList *self, const gchar *path)
 {
 	GvStationListPrivate *priv = self->priv;
 
+	/* This is a construct-only property, however it might also
+	 * be set internally by the gv_station_list_load() method.
+	 */
         if (!g_strcmp0(priv->load_path, path))
                 return;
 
@@ -848,12 +730,10 @@ gv_station_list_set_save_path(GvStationList *self, const gchar *path)
 {
 	GvStationListPrivate *priv = self->priv;
 
-        if (!g_strcmp0(priv->save_path, path))
-                return;
-
-        g_free(priv->save_path);
-        priv->save_path = g_strdup(path);
-        g_object_notify_by_pspec(G_OBJECT(self), properties[PROP_SAVE_PATH]);
+	/* This is a construct-only property */
+	g_assert_null(priv->save_path);
+	g_assert_nonnull(path);
+	priv->save_path = g_strdup(path);
 }
 
 static void
@@ -890,6 +770,12 @@ gv_station_list_set_property(GObject      *object,
 	TRACE_SET_PROPERTY(object, property_id, value, pspec);
 
 	switch (property_id) {
+	case PROP_DEFAULT_STATIONS:
+		gv_station_list_set_default_stations(self, g_value_get_string(value));
+		break;
+	case PROP_LOAD_PATHS:
+		gv_station_list_set_load_paths(self, g_value_get_pointer(value));
+		break;
 	case PROP_LOAD_PATH:
 		gv_station_list_set_load_path(self, g_value_get_string(value));
 		break;
@@ -1396,23 +1282,35 @@ gv_station_list_load(GvStationList *self)
 	/* This should be called only once at startup */
 	g_assert_null(priv->stations);
 
-	/* Try to load the station list, either from a user-provided path
-	 * (ie. during tests), either from the list of default locations.
+	/* If a single load path is defined, try to load the station list
+	 * from there. It must work. Failing to load from this path is a
+	 * fatal error.
+	 * Use-case: test suite
 	 */
 	if (priv->load_path) {
-		GError *error = NULL;
 		const gchar *path = priv->load_path;
+		GError *err = NULL;
 		gboolean ret;
 
-		ret = load_station_list_from_file(path, &priv->stations, &error);
+		ret = load_station_list_from_file(path, &priv->stations, &err);
 		if (ret == FALSE) {
 			ERROR("Failed to load station list from '%s': %s",
-			       path, error->message);
+			       path, err->message);
 			/* Program execution stops here */
 		}
 
-	} else if (priv->default_load_paths) {
-		gchar **paths = priv->default_load_paths;
+		INFO("Station list loaded from file '%s'", path);
+		goto finish;
+	}
+
+	/* If a list of load paths is defined, it's a best effort.  We try
+	 * them all in order, the first that succeeds wins, and is assigned
+	 * to the property 'load-path'.  If none succeeds, it's not a fatal
+	 * error, we simply keep going.
+	 * Use-case: real-life, xdg locations
+	 */
+	if (priv->load_paths) {
+		gchar **paths = priv->load_paths;
 		guint n_paths = g_strv_length(paths);
 		guint i;
 
@@ -1430,25 +1328,33 @@ gv_station_list_load(GvStationList *self)
 				continue;
 			}
 
+			INFO("Station list loaded from file '%s'", path);
 			gv_station_list_set_load_path(self, path);
-			break;
+			goto finish;
 		}
+
+		INFO("No valid station list file found");
 	}
 
-	/* Check if we got something */
-	if (priv->load_path) {
-		INFO("Station list loaded from file '%s'", priv->load_path);
-	} else {
+	/* If some hard-coded defaults are defined, try it. It is a fatal
+	 * error if we can't parse these defaults.
+	 */
+	if (priv->default_stations) {
 		gboolean ret;
 
-		INFO("No valid station list file found, using hard-coded default");
-		ret = load_station_list_from_string(DEFAULT_STATION_LIST, &priv->stations, NULL);
+		ret = load_station_list_from_string(priv->default_stations,
+				&priv->stations, NULL);
+
 		if (ret == FALSE) {
 			ERROR("Failed to load station list from hard-coded default");
 			/* Program execution stops here */
 		}
+
+		INFO("Station list loaded from hard-coded defaults");
+		goto finish;
 	}
 
+finish:
 	/* Dump the number of stations */
 	DEBUG("Station list has %u stations", gv_station_list_length(self));
 
@@ -1471,14 +1377,38 @@ gv_station_list_length(GvStationList *self)
 	return g_list_length(priv->stations);
 }
 
+/* Create a new station list with load paths and save path derived
+ * from XDG paths. In case none of the tentatice load paths work,
+ * ultimately the default_stations string will be used.
+ */
 GvStationList *
-gv_station_list_new(void)
+gv_station_list_new_from_xdg_dirs(const gchar *default_stations)
 {
-	return g_object_new(GV_TYPE_STATION_LIST, NULL);
+	GvStationList *station_list;
+	gchar **load_paths;
+	gchar *save_path;
+
+	load_paths = make_station_list_load_paths(STATION_LIST_FILE);
+	save_path = make_station_list_save_path(STATION_LIST_FILE);
+
+	station_list = g_object_new(GV_TYPE_STATION_LIST,
+			            "default-stations", default_stations,
+			            "load-paths", load_paths,
+			            "save-path", save_path,
+			            NULL);
+
+	g_free(save_path);
+	g_strfreev(load_paths);
+
+	return station_list;
 }
 
+/* Create a new station list with explicit load and save paths. There
+ * is no fallback in case we fail to parse the stations from the load
+ * path: this is considered a fatal error.
+ */
 GvStationList *
-gv_station_list_new_with_paths(const gchar *load_path, const gchar *save_path)
+gv_station_list_new_from_paths(const gchar *load_path, const gchar *save_path)
 {
 	return g_object_new(GV_TYPE_STATION_LIST,
 			    "load-path", load_path,
@@ -1490,41 +1420,6 @@ gv_station_list_new_with_paths(const gchar *load_path, const gchar *save_path)
  * GObject methods
  */
 
-static gchar **
-make_station_list_load_paths(void)
-{
-	const gchar *const *system_dirs;
-	const gchar *user_dir;
-	guint i, n_dirs;
-	gchar **dirs;
-
-	system_dirs = gv_get_app_system_data_dirs();
-	user_dir = gv_get_app_user_data_dir();
-
-	n_dirs = g_strv_length((gchar **) system_dirs) + 1;
-	dirs = g_malloc0_n(n_dirs + 1, sizeof(gchar *));
-	dirs[0] = g_build_filename(user_dir, STATION_LIST_FILE, NULL);
-	for (i = 1; i < n_dirs; i++) {
-		const gchar *dir;
-		dir = system_dirs[i - 1];
-		dirs[i] = g_build_filename(dir, STATION_LIST_FILE, NULL);
-	}
-
-	return dirs;
-}
-
-static gchar *
-make_station_list_save_path(void)
-{
-	const gchar *user_dir;
-	gchar *dir;
-
-	user_dir = gv_get_app_user_data_dir();
-	dir = g_build_filename(user_dir, STATION_LIST_FILE, NULL);
-
-	return dir;
-}
-
 static void
 gv_station_list_finalize(GObject *object)
 {
@@ -1538,7 +1433,7 @@ gv_station_list_finalize(GObject *object)
 	priv->finalization = TRUE;
 
 	/* Run any pending save operation */
-	if (priv->save_source_id > 0)
+	if (priv->save_timeout_id > 0)
 		when_timeout_save_station_list(self);
 
 	/* Free shuffled station list */
@@ -1557,11 +1452,11 @@ gv_station_list_finalize(GObject *object)
 	}
 	g_list_free(priv->stations);
 
-	/* Free paths */
+	/* Free resources */
+	g_free(priv->default_stations);
+	g_strfreev(priv->load_paths);
 	g_free(priv->save_path);
 	g_free(priv->load_path);
-	g_free(priv->default_save_path);
-	g_strfreev(priv->default_load_paths);
 
 	/* Chain up */
 	G_OBJECT_CHAINUP_FINALIZE(gv_station_list, object);
@@ -1571,21 +1466,8 @@ static void
 gv_station_list_constructed(GObject *object)
 {
 	GvStationList *self = GV_STATION_LIST(object);
-	GvStationListPrivate *priv = self->priv;
 
-	/* Initialize default paths */
-	priv->default_load_paths = make_station_list_load_paths();
-	priv->default_save_path = make_station_list_save_path();
-
-	/* Initialize save path if not set */
-	if (priv->save_path == NULL)
-		priv->save_path = g_strdup(priv->default_save_path);
-
-	/* DON'T initialize load path, this will be done just in time */
-
-	/* In version 4.1, the station file moved */
-	if (!gv_in_test_suite())
-		relocate_station_list_file_for_4_1(priv->save_path);
+	TRACE("%p", self);
 
 	/* Chain up */
 	G_OBJECT_CHAINUP_CONSTRUCTED(gv_station_list, object);
@@ -1615,15 +1497,21 @@ gv_station_list_class_init(GvStationListClass *class)
 	object_class->get_property = gv_station_list_get_property;
 	object_class->set_property = gv_station_list_set_property;
 
+	properties[PROP_DEFAULT_STATIONS] =
+	        g_param_spec_string("default-stations", "Default stations", NULL, NULL,
+	                            GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
+
+	properties[PROP_LOAD_PATHS] =
+	        g_param_spec_pointer("load-paths", "Load Paths", NULL,
+	                            GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
+
 	properties[PROP_LOAD_PATH] =
 	        g_param_spec_string("load-path", "Load Path", NULL, NULL,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE |
-				    G_PARAM_CONSTRUCT_ONLY);
+	                            GV_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
 
 	properties[PROP_SAVE_PATH] =
 	        g_param_spec_string("save-path", "Save Path", NULL, NULL,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE |
-				    G_PARAM_CONSTRUCT_ONLY);
+	                            GV_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 
