@@ -37,8 +37,9 @@ typedef struct _GvStationListIter GvStationListIter;
 
 /* Methods */
 
-GvStationList *gv_station_list_new (void);
-GvStationList *gv_station_list_new_with_paths(const gchar *load_path, const gchar *save_path);
+GvStationList *gv_station_list_new_from_xdg_dirs(const gchar *default_stations);
+GvStationList *gv_station_list_new_from_paths   (const gchar *load_path,
+                                                 const gchar *save_path);
 
 void  gv_station_list_load  (GvStationList *self);
 void  gv_station_list_save  (GvStationList *self);
