@@ -24,7 +24,8 @@
 #include <glib-object.h>
 #include <mutest.h>
 
-#include "framework/log.h"
+#include "default-stations.h"
+#include "base/log.h"
 #include "core/gv-station-list.h"
 
 #define TOUCHTMP(tmpl) g_close(g_mkstemp(tmpl), NULL)
@@ -34,7 +35,7 @@ station_list_load_default(mutest_spec_t *spec G_GNUC_UNUSED)
 {
 	GvStationList *s;
 
-	s = gv_station_list_new();
+	s = gv_station_list_new_from_xdg_dirs(DEFAULT_STATIONS);
 	g_object_add_weak_pointer(G_OBJECT(s), (gpointer *) &s);
 
 	mutest_expect("new() does not return null",
@@ -90,7 +91,7 @@ station_list_load_save_empty(mutest_spec_t *spec G_GNUC_UNUSED)
 			mutest_to_be, 0,
 			NULL);
 
-	s = gv_station_list_new_with_paths(input, output);
+	s = gv_station_list_new_from_paths(input, output);
 	g_object_add_weak_pointer(G_OBJECT(s), (gpointer *) &s);
 
 	mutest_expect("new_with_paths() does not return null",
@@ -142,7 +143,7 @@ station_list_load_save_empty(mutest_spec_t *spec G_GNUC_UNUSED)
 			mutest_not, mutest_to_be, 0,
 			NULL);
 
-	s = gv_station_list_new_with_paths(input, output);
+	s = gv_station_list_new_from_paths(input, output);
 	g_object_add_weak_pointer(G_OBJECT(s), (gpointer *) &s);
 
 	mutest_expect("new_with_paths() does not return null",
@@ -225,7 +226,7 @@ station_list_add_move_remove(mutest_spec_t *spec G_GNUC_UNUSED)
 	input = "/dev/null";
 	output = "/dev/null";
 
-	s = gv_station_list_new_with_paths(input, output);
+	s = gv_station_list_new_from_paths(input, output);
 	g_object_add_weak_pointer(G_OBJECT(s), (gpointer *) &s);
 
 	/* Create stations. Due to floating reference, stations are finalized
@@ -406,16 +407,14 @@ station_list_suite(mutest_suite_t *suite G_GNUC_UNUSED)
 {
 	gchar *tmpdir;
 
-	/* When a station list is created without giving it paths,
-	 * then it relies on XDG directories to find an existing
-	 * station list to load, and to save it in the user home
-	 * directory. For unit tests, this is not nice, we want to
-	 * be sure that we DON'T use anything that might already
-	 * exist in the filesystem.
+	/* A station list can be loaded/saved from/to the XDG directories,
+	 * so for unit tests, we must make sure to set the various XDG env
+	 * variables, so that we don't mess up with the test environment.
 	 */
 
 	tmpdir = g_dir_make_tmp("gv-station-list-XXXXXX", NULL);
 	g_assert_nonnull(tmpdir);
+
 	g_setenv("XDG_DATA_HOME", tmpdir, TRUE);
 	g_setenv("XDG_DATA_DIRS", tmpdir, TRUE);
 	g_setenv("XDG_CONFIG_HOME", tmpdir, TRUE);
