@@ -26,9 +26,9 @@
 #include <gio/gio.h>
 #include <glib-object.h>
 
-#include "framework/glib-additions.h"
-#include "framework/glib-object-additions.h"
-#include "framework/gv-framework.h"
+#include "base/glib-additions.h"
+#include "base/glib-object-additions.h"
+#include "base/gv-base.h"
 #include "core/gv-core.h"
 #ifdef GV_UI_ENABLED
 #include "ui/gv-ui.h"
@@ -409,13 +409,12 @@ g_variant_new_playback_status(GvPlayer *player)
 	state = gv_player_get_state(player);
 
 	switch (state) {
-	case GV_PLAYER_STATE_PLAYING:
-		state_str = "Playing";
-		break;
 	case GV_PLAYER_STATE_STOPPED:
-	default:
 		state_str = "Stopped";
 		break;
+	default:
+		state_str = "Playing";
+		break;
 	}
 
 	return g_variant_new_string(state_str);
@@ -448,6 +447,33 @@ g_variant_new_volume(GvPlayer *player)
 	return g_variant_new_double((gdouble) volume / 100.0);
 }
 
+static GVariant *
+g_variant_new_can_play(GvStationList *station_list)
+{
+	guint n_stations;
+
+	n_stations = gv_station_list_length(station_list);
+	return g_variant_new_boolean(n_stations > 0 ? TRUE : FALSE);
+}
+
+static GVariant *
+g_variant_new_can_go_prev(GvPlayer *player)
+{
+	gboolean has_prev;
+
+	has_prev = gv_player_get_prev_station(player) ? TRUE : FALSE;
+	return g_variant_new_boolean(has_prev);
+}
+
+static GVariant *
+g_variant_new_can_go_next(GvPlayer *player)
+{
+	gboolean has_next;
+
+	has_next = gv_player_get_next_station(player) ? TRUE : FALSE;
+	return g_variant_new_boolean(has_next);
+}
+
 /*
  * Dbus method handlers
  */
@@ -455,7 +481,7 @@ g_variant_new_volume(GvPlayer *player)
 static GVariant *
 method_raise(GvDbusServer  *dbus_server G_GNUC_UNUSED,
              GVariant       *params G_GNUC_UNUSED,
-             GError        **error G_GNUC_UNUSED)
+             GError        **err G_GNUC_UNUSED)
 {
 #ifdef GV_UI_ENABLED
 	gv_ui_present_main();
@@ -466,7 +492,7 @@ method_raise(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_quit(GvDbusServer  *dbus_server G_GNUC_UNUSED,
             GVariant       *params G_GNUC_UNUSED,
-            GError        **error G_GNUC_UNUSED)
+            GError        **err G_GNUC_UNUSED)
 {
 	gv_core_quit();
 
@@ -482,7 +508,7 @@ static GvDbusMethod root_methods[] = {
 static GVariant *
 method_play(GvDbusServer  *dbus_server G_GNUC_UNUSED,
             GVariant       *params G_GNUC_UNUSED,
-            GError        **error G_GNUC_UNUSED)
+            GError        **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -494,7 +520,7 @@ method_play(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_stop(GvDbusServer  *dbus_server G_GNUC_UNUSED,
             GVariant       *params G_GNUC_UNUSED,
-            GError        **error G_GNUC_UNUSED)
+            GError        **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -506,7 +532,7 @@ method_stop(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_toggle(GvDbusServer  *dbus_server G_GNUC_UNUSED,
               GVariant       *params G_GNUC_UNUSED,
-              GError        **error G_GNUC_UNUSED)
+              GError        **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -518,7 +544,7 @@ method_toggle(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_next(GvDbusServer  *dbus_server G_GNUC_UNUSED,
             GVariant       *params G_GNUC_UNUSED,
-            GError        **error G_GNUC_UNUSED)
+            GError        **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -531,7 +557,7 @@ method_next(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_prev(GvDbusServer  *dbus_server G_GNUC_UNUSED,
             GVariant       *params G_GNUC_UNUSED,
-            GError        **error G_GNUC_UNUSED)
+            GError        **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 
@@ -544,7 +570,7 @@ method_prev(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_open_uri(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                 GVariant       *params G_GNUC_UNUSED,
-                GError        **error G_GNUC_UNUSED)
+                GError        **err)
 {
 	GvPlayer *player  = gv_core_player;
 	GvStationList *station_list = gv_core_station_list;
@@ -555,7 +581,7 @@ method_open_uri(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 
 	/* Ensure URI is valid */
 	if (!is_uri_scheme_supported(uri)) {
-		g_set_error(error, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
+		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		            "URI scheme not supported.");
 		return NULL;
 	}
@@ -592,7 +618,7 @@ static GvDbusMethod player_methods[] = {
 static GVariant *
 method_get_tracks_metadata(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                            GVariant       *params,
-                           GError        **error G_GNUC_UNUSED)
+                           GError        **err G_GNUC_UNUSED)
 {
 	GvStationList *station_list = gv_core_station_list;
 	GVariantBuilder b;
@@ -617,7 +643,7 @@ method_get_tracks_metadata(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_add_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                  GVariant       *params,
-                 GError        **error)
+                 GError        **err)
 {
 	GvPlayer *player = gv_core_player;
 	GvStationList *station_list = gv_core_station_list;
@@ -630,14 +656,14 @@ method_add_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 
 	/* Ensure URI is valid */
 	if (!is_uri_scheme_supported(uri)) {
-		g_set_error(error, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
+		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		            "Invalid URI scheme for param 'Uri'.");
 		return NULL;
 	}
 
 	/* Handle 'after_track' */
 	if (!parse_track_id(after_track_id, station_list, &after_station)) {
-		g_set_error(error, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
+		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		            "Invalid param 'AfterTrack'.");
 		return NULL;
 	}
@@ -665,7 +691,7 @@ method_add_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_remove_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                     GVariant       *params,
-                    GError        **error)
+                    GError        **err)
 {
 	GvStationList *station_list = gv_core_station_list;
 	const gchar *track_id;
@@ -673,7 +699,7 @@ method_remove_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 
 	g_variant_get(params, "(&o)", &track_id);
 	if (!parse_track_id(track_id, station_list, &station)) {
-		g_set_error(error, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
+		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		            "Invalid param 'TrackId'.");
 		return NULL;
 	}
@@ -686,7 +712,7 @@ method_remove_track(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_go_to(GvDbusServer  *dbus_server G_GNUC_UNUSED,
              GVariant       *params,
-             GError        **error)
+             GError        **err)
 {
 	GvPlayer *player = gv_core_player;
 	GvStationList *station_list = gv_core_station_list;
@@ -697,7 +723,7 @@ method_go_to(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 
 	g_variant_get(params, "(&o)", &track_id);
 	if (!parse_track_id(track_id, station_list, &station)) {
-		g_set_error(error, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
+		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		            "Invalid param 'TrackId'.");
 		return NULL;
 	}
@@ -721,7 +747,7 @@ static GvDbusMethod tracklist_methods[] = {
 static GVariant *
 method_activate_playlist(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                          GVariant      *params,
-                         GError       **error)
+                         GError       **err)
 {
 	GvPlayer *player = gv_core_player;
 	GvStationList *station_list = gv_core_station_list;
@@ -731,7 +757,7 @@ method_activate_playlist(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 	g_variant_get(params, "(&o)", &playlist_id);
 
 	if (!parse_playlist_id(playlist_id, station_list, &station)) {
-		g_set_error(error, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
+		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		            "Invalid param 'PlaylistId'.");
 		return NULL;
 	}
@@ -748,7 +774,7 @@ method_activate_playlist(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 static GVariant *
 method_get_playlists(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                      GVariant      *params,
-                     GError       **error G_GNUC_UNUSED)
+                     GError       **err G_GNUC_UNUSED)
 {
 	GvStationList *station_list = gv_core_station_list;
 	GVariantBuilder b;
@@ -812,9 +838,9 @@ prop_get_false(GvDbusServer *dbus_server G_GNUC_UNUSED)
 static gboolean
 prop_set_error(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                GVariant       *value G_GNUC_UNUSED,
-               GError        **error)
+               GError        **err)
 {
-	g_set_error(error, G_DBUS_ERROR, G_DBUS_ERROR_NOT_SUPPORTED,
+	g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_NOT_SUPPORTED,
 	            "Setting this property is not supported.");
 
 	return FALSE;
@@ -886,7 +912,7 @@ prop_get_loop_status(GvDbusServer *dbus_server G_GNUC_UNUSED)
 static gboolean
 prop_set_loop_status(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                      GVariant       *value,
-                     GError        **error)
+                     GError        **err)
 {
 	GvPlayer *player = gv_core_player;
 	const gchar *loop_status;
@@ -904,7 +930,7 @@ prop_set_loop_status(GvDbusServer  *dbus_server G_GNUC_UNUSED,
 		repeat = FALSE;
 	} else {
 		/* Any other value should raise an error */
-		g_set_error(error, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
+		g_set_error(err, G_DBUS_ERROR, G_DBUS_ERROR_FAILED,
 		            "Invalid value.");
 
 		return FALSE;
@@ -926,7 +952,7 @@ prop_get_shuffle(GvDbusServer *dbus_server G_GNUC_UNUSED)
 static gboolean
 prop_set_shuffle(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                  GVariant       *value,
-                 GError        **error G_GNUC_UNUSED)
+                 GError        **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 	gboolean shuffle;
@@ -948,7 +974,7 @@ prop_get_volume(GvDbusServer *dbus_server G_GNUC_UNUSED)
 static gboolean
 prop_set_volume(GvDbusServer  *dbus_server G_GNUC_UNUSED,
                 GVariant       *value,
-                GError        **error G_GNUC_UNUSED)
+                GError        **err G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
 	gdouble volume;
@@ -983,33 +1009,24 @@ static GVariant *
 prop_get_can_play(GvDbusServer *dbus_server G_GNUC_UNUSED)
 {
 	GvStationList *station_list = gv_core_station_list;
-	guint n_stations;
 
-	n_stations = gv_station_list_length(station_list);
-
-	return g_variant_new_boolean(n_stations > 0 ? TRUE : FALSE);
+	return g_variant_new_can_play(station_list);
 }
 
 static GVariant *
 prop_get_can_go_prev(GvDbusServer *dbus_server G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
-	gboolean has_prev;
 
-	has_prev = gv_player_get_prev_station(player) ? TRUE : FALSE;
-
-	return g_variant_new_boolean(has_prev);
+	return g_variant_new_can_go_prev(player);
 }
 
 static GVariant *
 prop_get_can_go_next(GvDbusServer *dbus_server G_GNUC_UNUSED)
 {
 	GvPlayer *player = gv_core_player;
-	gboolean has_next;
 
-	has_next = gv_player_get_next_station(player) ? TRUE : FALSE;
-
-	return g_variant_new_boolean(has_next);
+	return g_variant_new_can_go_next(player);
 }
 
 static GvDbusProperty player_properties[] = {
@@ -1118,12 +1135,6 @@ on_player_notify(GvPlayer           *player,
 	const gchar *property_name = g_param_spec_get_name(pspec);
 
 	if (!g_strcmp0(property_name, "state")) {
-		GvPlayerState state = gv_player_get_state(player);
-
-		if (state != GV_PLAYER_STATE_PLAYING &&
-		    state != GV_PLAYER_STATE_STOPPED)
-			return;
-
 		gv_dbus_server_emit_signal_property_changed
 		(dbus_server, DBUS_IFACE_PLAYER, "PlaybackStatus",
 		 g_variant_new_playback_status(player));
@@ -1151,6 +1162,16 @@ on_player_notify(GvPlayer           *player,
 		(dbus_server, DBUS_IFACE_PLAYER, "Metadata",
 		 g_variant_new_metadata_map(station, metadata));
 
+		/* This signal should be sent only if there was a change */
+		gv_dbus_server_emit_signal_property_changed
+		(dbus_server, DBUS_IFACE_PLAYER, "CanGoPrevious",
+		 g_variant_new_can_go_prev(player));
+
+		/* This signal should be sent only if there was a change */
+		gv_dbus_server_emit_signal_property_changed
+		(dbus_server, DBUS_IFACE_PLAYER, "CanGoNext",
+		 g_variant_new_can_go_next(player));
+
 		/* This signal should be send only if the station's name
 		 * or the station's icon was changed.
 		 */
