@@ -23,8 +23,8 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "framework/glib-object-additions.h"
-#include "framework/gv-framework.h"
+#include "base/glib-object-additions.h"
+#include "base/gv-base.h"
 #include "ui/gv-ui-internal.h"
 #include "ui/gv-main-window.h"
 
@@ -95,7 +95,7 @@ struct _GvMainWindowManagerPrivate {
 	gint new_width;
 	gint new_height;
 	/* Window configuration */
-	guint save_window_configuration_source_id;
+	guint save_configuration_timeout_id;
 };
 
 typedef struct _GvMainWindowManagerPrivate GvMainWindowManagerPrivate;
@@ -145,13 +145,13 @@ gv_main_window_manager_save_configuration_now(GvMainWindowManager *self)
 }
 
 static gboolean
-when_timeout_save_window_configuration(GvMainWindowManager *self)
+when_timeout_save_configuration(GvMainWindowManager *self)
 {
 	GvMainWindowManagerPrivate *priv = self->priv;
 
 	gv_main_window_manager_save_configuration_now(self);
 
-	priv->save_window_configuration_source_id = 0;
+	priv->save_configuration_timeout_id = 0;
 
 	return G_SOURCE_REMOVE;
 }
@@ -161,11 +161,9 @@ gv_main_window_manager_save_configuration_delayed(GvMainWindowManager *self)
 {
 	GvMainWindowManagerPrivate *priv = self->priv;
 
-	if (priv->save_window_configuration_source_id > 0)
-		g_source_remove(priv->save_window_configuration_source_id);
-
-	priv->save_window_configuration_source_id =
-	        g_timeout_add_seconds(SAVE_DELAY, (GSourceFunc) when_timeout_save_window_configuration,
+	g_clear_handle_id(&priv->save_configuration_timeout_id, g_source_remove);
+	priv->save_configuration_timeout_id =
+	        g_timeout_add_seconds(SAVE_DELAY, (GSourceFunc) when_timeout_save_configuration,
 	                              self);
 }
 
@@ -476,8 +474,8 @@ gv_main_window_manager_finalize(GObject *object)
 	TRACE("%p", object);
 
 	/* Run any pending save operation */
-	if (priv->save_window_configuration_source_id > 0)
-		when_timeout_save_window_configuration(self);
+	if (priv->save_configuration_timeout_id > 0)
+		when_timeout_save_configuration(self);
 
 	/* Release resources */
 	g_object_unref(priv->main_window);
@@ -528,19 +526,17 @@ gv_main_window_manager_class_init(GvMainWindowManagerClass *class)
 	properties[PROP_MAIN_WINDOW] =
 	        g_param_spec_object("main-window", "Main window", NULL,
 	                            GV_TYPE_MAIN_WINDOW,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_WRITABLE |
-				    G_PARAM_CONSTRUCT_ONLY);
+	                            GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
 
 	properties[PROP_STATUS_ICON_MODE] =
 	        g_param_spec_boolean("status-icon-mode", "Status icon mode", NULL,
 	                             FALSE,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_WRITABLE |
-				     G_PARAM_CONSTRUCT_ONLY);
+	                             GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
 
 	properties[PROP_AUTOSET_HEIGHT] =
 	        g_param_spec_boolean("autoset-height", "Autoset height", NULL,
 	                             FALSE,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                             GV_PARAM_READWRITE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 }
