@@ -23,8 +23,8 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "framework/glib-object-additions.h"
-#include "framework/gv-framework.h"
+#include "base/glib-object-additions.h"
+#include "base/gv-base.h"
 #include "core/gv-core.h"
 #include "ui/gtk-additions.h"
 #include "ui/gv-ui-enum-types.h"
@@ -163,7 +163,7 @@ gv_main_window_compute_natural_height(GvMainWindow *self)
 #endif
 
 	/*
-	 * Here comes a hacky piece of code !
+	 * Here comes a hacky piece of code!
 	 *
 	 * Problem: from the moment the station tree view is within a scrolled
 	 * window, the height is not handled smartly by GTK anymore. By default,
@@ -176,7 +176,7 @@ gv_main_window_compute_natural_height(GvMainWindow *self)
 	 * - too early, get_preferred_size() calls return junk.
 	 * - in some signal handlers, get_preferred_size() calls return junk.
 	 *
-	 * Plus, we resize the window here, is the context safe to do that ?
+	 * Plus, we resize the window here, is the context safe to do that?
 	 *
 	 * For these reasons, it's safer to never call this function directly,
 	 * but instead always delay the call for an idle moment.
@@ -1098,31 +1098,29 @@ gv_main_window_class_init(GvMainWindowClass *class)
 	properties[PROP_STATUS_ICON_MODE] =
 	        g_param_spec_boolean("status-icon-mode", "Status icon mode", NULL,
 	                             FALSE,
-	                             GV_PARAM_DEFAULT_FLAGS | G_PARAM_WRITABLE |
-				     G_PARAM_CONSTRUCT_ONLY);
+	                             GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
 
 	properties[PROP_PRIMARY_MENU] =
 	        g_param_spec_object("primary-menu", "Primary menu", NULL,
 	                            G_TYPE_MENU_MODEL,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE |
-				    G_PARAM_CONSTRUCT_ONLY);
+	                            GV_PARAM_READWRITE | G_PARAM_CONSTRUCT_ONLY);
 
 	properties[PROP_NATURAL_HEIGHT] =
 	        g_param_spec_int("natural-height", "Natural height", NULL,
 	                         0, G_MAXINT, 0,
-	                         GV_PARAM_DEFAULT_FLAGS | G_PARAM_READABLE);
+	                         GV_PARAM_READABLE);
 
 	properties[PROP_CLOSE_ACTION] =
 	        g_param_spec_enum("close-action", "Close Action", NULL,
 	                          GV_TYPE_MAIN_WINDOW_CLOSE_ACTION,
 	                          DEFAULT_CLOSE_ACTION,
-	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                          GV_PARAM_READWRITE);
 
 	properties[PROP_THEME_VARIANT] =
 	        g_param_spec_enum("theme-variant", "Theme variant", NULL,
 	                          GV_TYPE_MAIN_WINDOW_THEME_VARIANT,
 	                          DEFAULT_THEME_VARIANT,
-	                          GV_PARAM_DEFAULT_FLAGS | G_PARAM_READWRITE);
+	                          GV_PARAM_READWRITE);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 
