@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -19,8 +19,7 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GOODVIBES_UI_GV_MAIN_WINDOW_H__
-#define __GOODVIBES_UI_GV_MAIN_WINDOW_H__
+#pragma once
 
 #include <glib-object.h>
 #include <gtk/gtk.h>
@@ -33,6 +32,11 @@ G_DECLARE_FINAL_TYPE(GvMainWindow, gv_main_window, GV, MAIN_WINDOW, GtkApplicati
 
 /* Data types */
 
+typedef enum {
+	GV_MAIN_WINDOW_CLOSE_QUIT,
+	GV_MAIN_WINDOW_CLOSE_CLOSE,
+} GvMainWindowCloseAction;
+
 typedef enum {
 	GV_MAIN_WINDOW_THEME_DEFAULT,
 	GV_MAIN_WINDOW_THEME_DARK,
@@ -41,15 +45,18 @@ typedef enum {
 
 /* Methods */
 
-GtkWidget *gv_main_window_new(GApplication *application, gboolean status_icon_mode);
+GvMainWindow *gv_main_window_new(GApplication *application, GMenuModel *primary_menu, gboolean status_icon_mode);
 
+void gv_main_window_play_stop(GvMainWindow *self);
 void gv_main_window_resize_height(GvMainWindow *self, gint height);
 
 /* Property accessors */
 
+GMenuModel *             gv_main_window_get_primary_menu   (GvMainWindow *self);
 gint                     gv_main_window_get_natural_height (GvMainWindow *self);
+GvMainWindowCloseAction  gv_main_window_get_close_action   (GvMainWindow *self);
+void                     gv_main_window_set_close_action   (GvMainWindow *self,
+                                                            GvMainWindowCloseAction action);
 GvMainWindowThemeVariant gv_main_window_get_theme_variant  (GvMainWindow *self);
 void                     gv_main_window_set_theme_variant  (GvMainWindow *self,
                                                             GvMainWindowThemeVariant variant);
-
-#endif /* __GOODVIBES_UI_GV_MAIN_WINDOW_H__ */
