@@ -24,8 +24,8 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "framework/glib-object-additions.h"
-#include "framework/gv-framework.h"
+#include "base/glib-object-additions.h"
+#include "base/gv-base.h"
 #include "core/gv-core.h"
 #include "ui/gtk-additions.h"
 #include "ui/gv-ui-internal.h"
@@ -299,7 +299,7 @@ gv_station_dialog_setup_widgets(GvStationDialog *self)
 	/* We don't allow creating a station without an empty uri, therefore
 	 * the save button is insensitive when the uri empty. We can set it
 	 * insensitive now because of the following code...
-	 * Watch out if you change something here !
+	 * Watch out if you change something here!
 	 */
 	gtk_widget_set_sensitive(priv->save_button, FALSE);
 
@@ -400,8 +400,7 @@ gv_station_dialog_class_init(GvStationDialogClass *class)
 
 	properties[PROP_STATION] =
 	        g_param_spec_object("station", "Station", NULL, GV_TYPE_STATION,
-	                            GV_PARAM_DEFAULT_FLAGS | G_PARAM_WRITABLE |
-	                            G_PARAM_CONSTRUCT_ONLY);
+	                            GV_PARAM_WRITABLE | G_PARAM_CONSTRUCT_ONLY);
 
 	g_object_class_install_properties(object_class, PROP_N, properties);
 }
