@@ -23,8 +23,8 @@
 #include <glib-object.h>
 #include <gtk/gtk.h>
 
-#include "framework/glib-object-additions.h"
-#include "framework/gv-framework.h"
+#include "base/glib-object-additions.h"
+#include "base/gv-base.h"
 #include "core/gv-core.h"
 #include "ui/gv-station-context-menu.h"
 
@@ -117,7 +117,7 @@ on_player_notify_station(GvPlayer           *player,
 		if (iter_station)
 			g_object_unref(iter_station);
 
-		/* Next ! */
+		/* Next! */
 		can_iter = gtk_tree_model_iter_next(tree_model, &iter);
 	}
 }
@@ -194,7 +194,7 @@ on_tree_view_row_activated(GvStationsTreeView *self,
 }
 #else
 static gboolean
-idle_tree_view_row_activated(GvStationsTreeView *self)
+when_idle_tree_view_row_activated(GvStationsTreeView *self)
 {
 	GvStationsTreeViewPrivate *priv = self->priv;
 	GtkTreeView *tree_view = GTK_TREE_VIEW(self);
@@ -254,7 +254,7 @@ on_tree_view_row_activated(GvStationsTreeView *self,
 	 * We must give time to the 'drag-begin' signal to be emitted.
 	 */
 
-	g_idle_add((GSourceFunc) idle_tree_view_row_activated, self);
+	g_idle_add((GSourceFunc) when_idle_tree_view_row_activated, self);
 }
 #endif
 
