@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -19,12 +19,9 @@
  * along with this program. If not, see <http://www.gnu.org/licenses/>.
  */
 
-#ifndef __GOODVIBES_UI_GV_UI_HELPERS_H__
-#define __GOODVIBES_UI_GV_UI_HELPERS_H__
+#pragma once
 
 #include <glib-object.h>
 
 void gv_value_transform_enum_string(const GValue *src_value, GValue *dest_value);
 void gv_value_transform_string_enum(const GValue *src_value, GValue *dest_value);
-
-#endif /* __GOODVIBES_UI_GV_UI_HELPERS_H__ */
