@@ -1,7 +1,7 @@
 /*
  * Goodvibes Radio Player
  *
- * Copyright (C) 2015-2018 Arnaud Rebillout
+ * Copyright (C) 2015-2020 Arnaud Rebillout
  *
  * SPDX-License-Identifier: GPL-3.0-or-later
  *
@@ -23,8 +23,7 @@
  * This header contains definitions to be used internally by ui files
  */
 
-#ifndef __GOODVIBES_UI_GV_UI_INTERNAL_H__
-#define __GOODVIBES_UI_GV_UI_INTERNAL_H__
+#pragma once
 
 #include <gio/gio.h>
 
@@ -36,7 +35,7 @@
 extern GSettings *gv_ui_settings;
 
 extern GvStatusIcon        *gv_ui_status_icon;
-extern GtkWidget           *gv_ui_main_window;
+extern GvMainWindow        *gv_ui_main_window;
 extern GvMainWindowManager *gv_ui_main_window_manager;
 
 /*
@@ -48,5 +47,3 @@ extern GvMainWindowManager *gv_ui_main_window_manager;
 #define GV_UI_GROUP_SPACING  18
 #define GV_UI_ELEM_SPACING   6
 #define GV_UI_COLUMN_SPACING 12
-
-#endif /* __GOODVIBES_UI_GV_UI_INTERNAL_H__ */
